@@ -62,24 +62,26 @@ if (requireNamespace("lme4")) {
   )
 }
 
-## ----eval=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  data("lung", package = "survival")
-#  # remove category 3 (outlier, not nice in the plot)
-#  lung <- subset(lung, subset = ph.ecog %in% 0:2)
-#  lung$sex <- factor(lung$sex, labels = c("male", "female"))
-#  lung$ph.ecog <- factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
-#  
-#  m <- survival::coxph(survival::Surv(time, status) ~ sex + age + ph.ecog, data = lung)
-#  
-#  # predicted risk-scores
-#  pr <- ggpredict(m, c("sex", "ph.ecog"))
-#  plot(pr)
-#  
-#  # probability of survival
-#  pr <- ggpredict(m, c("sex", "ph.ecog"), type = "surv")
-#  plot(pr)
-#  
-#  # cumulative hazards
-#  pr <- ggpredict(m, c("sex", "ph.ecog"), type = "cumhaz")
-#  plot(pr)
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+data("lung", package = "survival")
+# remove category 3 (outlier, not nice in the plot)
+lung <- subset(lung, subset = ph.ecog %in% 0:2)
+lung$sex <- factor(lung$sex, labels = c("male", "female"))
+lung$ph.ecog <- factor(lung$ph.ecog, labels = c("good", "ok", "limited"))
+
+m <- survival::coxph(survival::Surv(time, status) ~ sex + age + ph.ecog, data = lung)
+
+# predicted risk-scores
+pr <- ggpredict(m, c("sex", "ph.ecog"))
+plot(pr)
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# probability of survival
+pr <- ggpredict(m, c("sex", "ph.ecog"), type = "surv")
+plot(pr)
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+# cumulative hazards
+pr <- ggpredict(m, c("sex", "ph.ecog"), type = "cumhaz")
+plot(pr)
 
